@@ -55,14 +55,28 @@ class Quality:
         """
         return {
             'outOfBounds': self._find_invalid_data_values(),
-            'timeVectorStep': self._check_time_vector()
+            'timeVectorStep': self._check_time_vector(),
+            'medianLwp': self._check_median_lwp(),
         }
 
     def close(self) -> None:
         """Close the inspected file."""
         self._nc.close()
 
-    def _check_time_vector(self):
+    def _check_median_lwp(self) -> list:
+        invalid = []
+        if self._nc.cloudnet_file_type != 'mwr' or 'lwp' not in self._nc.variables:
+            return invalid
+        min_threshold = 0
+        max_threshold = 10
+        median_lwp = np.median(self._nc.variables['lwp'][:]) / 1000
+        if not (min_threshold < median_lwp < max_threshold):
+            invalid.append(('median lwp',
+                            (median_lwp, median_lwp),
+                            f'{str(min_threshold), str(max_threshold)}'))
+        return invalid
+
+    def _check_time_vector(self) -> list:
         invalid = []
         time = self._nc['time'][:]
         if len(time) == 1:
@@ -102,7 +116,7 @@ class Quality:
                     self.n_metadata_test_failures += 1
         return invalid
 
-    def _check_attribute(self, name: str, ignore_model: Optional[bool] = False):
+    def _check_attribute(self, name: str, ignore_model: Optional[bool] = False) -> list:
         invalid = []
         if ignore_model is True and self._nc.cloudnet_file_type == 'model':
             return invalid
